@@ -36,9 +36,14 @@ def handle_exceptions(func):
                 if not validate_parameters(function=func):
                     notification_channel = "empty-parameters"
 
+            use_default_response_message_key = True
             if hasattr(e, "custom_exception"):
                 public_message = e.args[0] if e.args else e.message if hasattr(e, 'message') else 'Unknown'
                 status_code = e.code
+                use_default_response_message_key = (
+                    e.use_default_response_message_key
+                    if hasattr(e, 'use_default_response_message_key') else True
+                )
                 send_notification = hasattr(e, "silent") and not e.silent
                 notification_channel = "soft-errors"
             else:
@@ -56,6 +61,6 @@ def handle_exceptions(func):
                 app.logger.error(message)
                 send_critical_error(message=message, channel=notification_channel)
 
-            return public_message, status_code
+            return public_message, status_code, use_default_response_message_key
 
     return inner_function
