@@ -5,8 +5,8 @@ from wedeliver_core import WeDeliverCore
 from flask import request
 
 
-def format_exception(exception, user=None):
-    app = WeDeliverCore.getApp()
+def format_exception(exception, user=None, status_code=None, soft_message=None):
+    app = WeDeliverCore.get_app()
     user = user or dict()
     try:
         caller_frame = request.path
@@ -46,6 +46,11 @@ def format_exception(exception, user=None):
     except Exception:
         node = "Unknown"
 
+    if status_code:
+        status_code = "\nStatus Code: {0}".format(status_code)
+    if soft_message:
+        soft_message = "\nSoft Message: {0}".format(soft_message)
+
     return """Node: {node}
 Time: {_time}
 Env: {env}
@@ -54,7 +59,7 @@ API: {call}
 User: {user}
 Role: {role}
 Args: {args}
-Form: {form}
+Form: {form}{status_code}{soft_message}
 Error: {error}""".format(
         env=app.config.get("FLASK_ENV"),
         call=caller_frame,
@@ -66,4 +71,6 @@ Error: {error}""".format(
         args=args,
         form=form,
         error=exception,
+        status_code=status_code or "",
+        soft_message=soft_message or "",
     )
