@@ -3,7 +3,7 @@ import inspect
 import traceback
 from flask import request
 
-from wedeliver_core.wedeliver_core.helpers.get_embedded_function import (
+from wedeliver_core.helpers.get_embedded_function import (
     get_embedded_function,
 )
 
